(function ($) {
	$(document).ready(function () {
        let apiKeyField = $('#isfWordpressApiKey');

        let spinner = $('.spinner');

        function addNotice(type, message) {
            $('.message').empty();

            let noticeClass = 'notice-error';
            switch (type) {
                case 'success': noticeClass = 'notice-success'; break;
                case 'warning': noticeClass = 'notice-warning'; break;
                default: noticeClass = 'notice-error'; break;
            }

            let noticeHtml = `
                <div class="banner notice ${noticeClass} is-dismissible ml-0" style="margin-top: 1rem; margin-bottom: 1rem">
                    <p>${message}</p>
                </div>`;

            $('.message').append(noticeHtml);
        }

        // Check API key button click
		$("#checkApiKeyButton").on('click', function (e) {
			e.preventDefault();
            $('.message').empty();

            let api_key = apiKeyField.val();

            if (api_key.trim() === '') {
                console.log('No API key');
                addNotice('error', 'Please enter an API key to continue.');
                return;
            }

            spinner.addClass('is-active');

            $.ajax({
                url: isf_ajax_object.ajax_url,
                type: "POST",
                data: {
                    action: 'verify_api_key',
                    nonce: isf_ajax_object.nonce,
                    api_key: api_key,
                },
                success: function (response) {
                    console.log(response);
                    if (response.success && response.data.checkDomain) {
                        addNotice('success', 'API key successfully verified and saved.');
                        setTimeout(function () {
                            // reload the settings page
                            location.reload();
                            spinner.removeClass('is-active');
                        },  1500);
                    } else {
                        console.error("Error validating API key. Domain not match!");
                        addNotice('error', 'Error validating API key. Please check your API key and try again.');
                        spinner.removeClass('is-active');
                    }
                },
                error: function (error, textStatus, errorThrown) {
                    console.error('AJAX Error:', error);
                    if(error.status === 400 || error.status === 401){
                        addNotice('error', 'Error validating API key. Please check your API key and try again.');
                    } else {
                        addNotice('error', 'Error validating API key. Please retry again later.');
                    }
                    spinner.removeClass('is-active');
                },
            });
		});

        // Disable the Save button when the API key input changes.
        // apiKeyField.on('change keyup paste input', function() {
        //     // submitButton.prop('disabled', true);
        // });

        // PURGE CACHE BY URL
        $('#wp-admin-bar-purgeCacheByUrl').on('click', function (e) {
            e.preventDefault();
            // $('.message').empty();

            // spinner.addClass('is-active');

            var currentUrl = window.location.href;

            console.log('currentUrl');
            console.log(currentUrl);

            $.ajax({
                url: isf_ajax_object.ajax_url,
                type: "POST",
                data: {
                    action: 'purge_by_url',
                    nonce: isf_ajax_object.nonce,
                    urls_to_purge: [ currentUrl ]
                },
                success: function (response) {
                    console.log(response);
                    if (response.success && response.data.result) {
                        alert('Cache successfully purged for this page.');
                    } else {
                        alert('Cache purged unsuccessfully, please try again later.');
                    }
                },
                error: function (error, textStatus, errorThrown) {
                    console.error('AJAX Error:', error);
                    if(error.status === 400 || error.status === 401){
                        alert('Error purging cache for this page. Please check your API key and try again later.');
                    } else if (error.status === 429) {
                        alert('Error purging cache for this page. Rate limit exceeded. Please try again later.');
                    } else {
                        alert('Error purging cache for this page. Please retry again later.');
                    }
                },
            });
        })

        // PURGE CACHE BY URL IN EDIT MODE GUTENBERG EDITOR
        $(document).on('click', '#purge-cache-by-url-edit-gutenberg', function (e) {
            e.preventDefault();
            $('.message').empty();
            let spinner = $(this).next(".spinner");

            spinner.addClass('is-active');

            var postID = $('#purge-cache-by-url-edit-gutenberg').data('post-id');

            $.ajax({
                url: isf_ajax_object.ajax_url,
                type: "POST",
                data: {
                    action: 'purge_by_url_edit',
                    nonce: isf_ajax_object.nonce,
                    post_id: postID
                },
                success: function (response) {
                    console.log(response);
                    if (response.success && response.data.result) {
                        addNotice('success', 'Cache successfully purged for this page.');
                        // alert('Cache successfully purged for this page.');
                    } else {
                        addNotice('error', 'Error purging cache for this page. Please retry again later.');
                        // alert('Cache purged unsuccessfully, please try again later.');
                    }
                    spinner.removeClass('is-active');
                },
                error: function (error, textStatus, errorThrown) {
                    console.error('AJAX Error:', error);
                    if(error.status === 400 || error.status === 401){
                        addNotice('error', 'Error purging cache for this page. Please check your API key and try again later.');
                        // alert('Error purging cache for this page. Please check your API key and try again later.');
                    } else if (error.status === 429) {
                        addNotice('error', 'Error purging cache for this page. Rate limit exceeded. Please try again later.');
                    } else {
                        addNotice('error', 'Error purging cache for this page. Please retry again later.');
                        // alert('Error purging cache for this page. Please retry again later.');
                    }
                    spinner.removeClass('is-active');
                },
            });
        });

        // PURGE CACHE BY URL IN EDIT MODE CLASSIC EDITOR
        $(document).on('click', '#purge-cache-by-url-edit-classic', function (e) {
            e.preventDefault();
            $('.message').empty();

            spinner.addClass('is-active');

            var postID = $('#purge-cache-by-url-edit-classic').data('post-id');

            $.ajax({
                url: isf_ajax_object.ajax_url,
                type: "POST",
                data: {
                    action: 'purge_by_url_edit',
                    nonce: isf_ajax_object.nonce,
                    post_id: postID
                },
                success: function (response) {
                    console.log(response);
                    if (response.success && response.data.result) {
                        addNotice('success', 'Cache successfully purged for this page.');
                        // alert('Cache successfully purged for this page.');
                    } else {
                        addNotice('error', 'Error purging cache for this page. Please retry again later.');
                        // alert('Error purging cache for this page. Please retry again later.');
                    }
                    spinner.removeClass('is-active');
                },
                error: function (error, textStatus, errorThrown) {
                    console.error('AJAX Error:', error);
                    if(error.status === 400 || error.status === 401){
                        addNotice('error', 'Error purging cache for this page. Please check your API key and try again later.');
                        // alert('Error purging cache for this page. Please check your API key and try again later.');
                    } else {
                        addNotice('error', 'Error purging cache for this page. Please retry again later.');
                        // alert('Error purging cache for this page. Please retry again later.');
                    }
                    spinner.removeClass('is-active');
                },
            });
        });

        // PURGE ALL CACHE
        $('#purgeByPatternButton').on('click', function (e) {
            e.preventDefault();
            $('#confirmationSection').show();
        });

        $('#cancelClearCache').on('click', function (e) {
            e.preventDefault();
            $('#confirmationSection').hide();
        });

        $("#confirmClearCache").on('click', function (e) {
			e.preventDefault();

            spinner.addClass('is-active');

            $.ajax({
                url: isf_ajax_object.ajax_url,
                type: "POST",
                data: {
                    action: 'purge_by_pattern',
                    nonce: isf_ajax_object.nonce,
                },
                success: function (response) {
                    console.log(response);
                    if (response.data.result && response.data.domain) {
                        $('#confirmationSection').hide();
                        addNotice('success', `Purge cache successfully requested for domain <b> ${response.data.domain}</b>. <br>
                            This operation may take a few minutes to propagate across all data centers.`
                        );
                    } else {
                        console.error("Error clearing cache!");
                        addNotice('error', 'Error clearing cache. Please retry again later.');
                    }
                    spinner.removeClass('is-active');
                },
                error: function (error, textStatus, errorThrown) {
                    console.error('AJAX Error:', error);
                    if(error.status){
                        switch (error.status){
                            case 400: addNotice('error', 'Error clearing cache. The given data was invalid.'); break;
                            case 401: addNotice('error', 'Error validating API key. Please check your API key and try again.'); break;
                            case 422: addNotice('error', 'Error clearing cache. The regex pattern is not valid.'); break;
                            case 429:
                                let lastPurge = error.responseJSON.data.last_purge || 'NA';
                                let remainingminutes = error.responseJSON.data.remaining_minutes || 'NA';
                                addNotice('warning', `Please wait <b>${remainingminutes} minutes</b> before request a new cache reset. <br>
                                    Last cache reset request: ${lastPurge}`
                                );
                                break;

                                default: addNotice('error', 'Error clearing cache. Please retry again later.'); break;
                        }
                    } else {
                        addNotice('error', 'Error clearing cache. Please retry again later.');
                    }

                    spinner.removeClass('is-active');
                },
            });
		});

	});
})(jQuery);
