<?php

/**
 *  Aggiorna gli headers HTTP aggiungendo l'header 'Cache-Tag' con gli ID dei post correnti in pagina.
 *  Questa funzione è collegata all'hook 'wp_headers'.
 * @param $headers
 * @return mixed
 */
function wp_isf_headers($headers) {
    // Verifica se l'utente non è nell'area di amministrazione di WordPress
    if (!is_admin()) {
        $object_ids = [];

        // Ottengo gli ID degli oggetti in base al tipo di pagina
        if (is_front_page()) {
            $object_ids = cache_handle_tag('front');
        } elseif (is_single() || is_page()) {
            $object_ids[] = 'p' . get_the_ID();
            $object_ids = array_merge($object_ids, get_category_and_taxonomy_ids(get_the_ID()));
        } elseif (is_archive()) {
            $object_ids = cache_handle_tag('archive');
        }

        // Rimuovo gli ID duplicati
        $object_ids = array_unique($object_ids);

        // Aggiungo agli headers come 'Cache-Tag'
        if (!empty($object_ids)) {
            header('Cache-Tag: ' . implode(',', $object_ids));
        }
    }
    // Restituisce gli headers aggiornati
    return $headers;
}

/**
 *  Ottiene gli ID dei post correnti in base al tipo di pagina specificato.
 * @param $type
 * @return array|mixed
 */
function cache_handle_tag($type) {
    $object_ids = [];

    // Inizia il loop di WordPress per ottenere i post correnti
    if (have_posts()) {
        while (have_posts()) {
            the_post();
            $object_ids[] = 'p' . get_the_ID();
            $object_ids = array_merge($object_ids, get_category_and_taxonomy_ids(get_the_ID()));
        }
    }

    // Aggiungi l'ID della tassonomia corrente se siamo in un archivio
    if ($type === 'archive') {
        $queried_object = get_queried_object();
        if (isset($queried_object->taxonomy)) {
            $object_ids[] = 't' . $queried_object->term_id;
        }
    }

    // Aggiungi gli ID delle categorie e delle tassonomie
    $categories = get_the_category();
    foreach ($categories as $category) {
        $object_ids[] = 'c' . $category->term_id;
    }

    // Restituisce gli ID degli oggetti correnti in pagina
    return $object_ids;
}

/**
 * Retrieves the IDs of categories, tags, and other taxonomy terms associated with a post.
 *
 * @param int $post_id The ID of the post.
 * @return array The IDs of categories, tags, and taxonomy terms.
 */
function get_category_and_taxonomy_ids($post_id) {
    $term_ids = [];

    // Fetch post type to ensure it's valid
    $post_type = get_post_type($post_id);
    if (!$post_type) {
        return $term_ids; // Return empty if post type is invalid
    }

    // Get all registered taxonomies for this post type
    $taxonomies = get_object_taxonomies($post_type, 'objects');

    // Loop through each taxonomy and get the terms associated with the post
    foreach ($taxonomies as $taxonomy_name => $taxonomy) {
        $terms = get_the_terms($post_id, $taxonomy_name);
        if ($terms && !is_wp_error($terms)) {
            foreach ($terms as $term) {
                // Check for specific taxonomies (category and post_tag)
                if ($taxonomy_name === 'category') {
                    $term_ids[] = 'c' . $term->term_id; // Prefix with 'c' for categories
                } elseif ($taxonomy_name === 'post_tag') {
                    $term_ids[] = 't' . $term->term_id; // Prefix with 't' for tags
                } else {
                    // Prefix with the first letter of the taxonomy name for other taxonomies
                    $term_ids[] = $taxonomy_name[0] . $term->term_id;
                }
            }
        }
    }

    // Remove duplicates if necessary
    $term_ids = array_unique($term_ids);

    return $term_ids;
}


// Hook to 'template_redirect' to ensures that the headers are set after the main query is executed.
add_action('template_redirect', 'wp_isf_headers');
