<?php

/**
 *
 * Add iSF settings page to WordPress admin menu
 *
 */
function addIsfPluginSettingsInAdminMenu() {
    global $wp_filesystem;

    // Load the Filesystem API
    if ( ! function_exists('WP_Filesystem') ) {
        require_once(ABSPATH . 'wp-admin/includes/file.php');
    }

    // Initialize the Filesystem API
    WP_Filesystem();

    // Get the SVG file path
    $svg_file_path = plugin_dir_path(__FILE__) . 'assets/isf-logo-svg.svg';

    // Initialize $svg_icon_base64
    $svg_icon_base64 = '';

    // Check if the file exists and read it using WP_Filesystem
    if ( $wp_filesystem->exists($svg_file_path) ) {
        // Read the SVG file
        $svg_icon = $wp_filesystem->get_contents($svg_file_path);
        $svg_icon_base64 = 'data:image/svg+xml;base64,' . base64_encode($svg_icon);
    } else {
        // Handle error or fallback
        $svg_icon_base64 = 'dashicons-performance';
    }

    add_menu_page(
        __('iSmartFrame WordPress Plugin', 'isf-plugin'),
        __('iSmartFrame', 'isf-plugin'),
        'manage_options',
        'ismartframe',
        'renderPluginSettingPageIsfWordpressApp',
        $svg_icon_base64
    );

    // Add the 'Impostazioni' submenu item
    add_submenu_page(
        'ismartframe',
        __('iSmartFrame Plugin Settings', 'isf-plugin'),
        __('Settings', 'isf-plugin'),
        'manage_options',
        'ismartframe', // Same slug as the main menu page
        'renderPluginSettingPageIsfWordpressApp'
    );

    // Add the 'Logs' submenu item
    add_submenu_page(
        'ismartframe',
        __('iSmartFrame Plugin Logs', 'isf-plugin'),
        __('Logs', 'isf-plugin'),
        'manage_options',
        'isf-wordpress-plugin-logs',
        'renderPluginLogsPage'
    );
}

add_action('admin_menu', 'addIsfPluginSettingsInAdminMenu');

/**
 *
 * Credentials page structure
 *
 */
function renderPluginSettingPageIsfWordpressApp() {
    ?>
    <div class="banner notice notice-warning is-dismissible">
        <img src="<?php echo esc_url(plugins_url('assets/isf-logo.png', __FILE__)); ?>" alt="First-time ISF configuration">
        <div class="banner-text">
            <h3>First time on iSmartFrame?</h3>
            <p><a href="https://ismartframe.com/">Get started now</a>, install the app and accelerate your website speed!</p>
        </div>
    </div>

    <div class="isf-settings-container">
        <div class="isf-left-column">
            <form action="options.php" method="post" id="isfPluginOptionsForm">
                <?php
                settings_fields('isfWordpressPluginOptions');
                do_settings_sections('isfWordpressOptions'); ?>
                <button id="checkApiKeyButton" class="button button-primary">Check API key and Save</button>
            </form>
        </div>

        <div class="isf-right-column">
            <h3>How to generate your API Key</h3>
            <p>To generate your API key, follow these steps:</p>
            <ol>
                <li>Log in to your account on <a href="https://app.ismartframe.com/">app.ismartframe.com</a></li>
                <li>Navigate to your domain section in your dashboard.</li>
                <li>Locate the "API Key" section, click 'Generate' and copy it.</li>
                <li>Paste it into the field in the plugin settings.</li>
            </ol>
        </div>
    </div>
    <?php
    $options = get_option('isfWordpressPluginOptions');
    if (isset($options['api_key']) && $options['api_key'] !== '') {
    ?>
        <div class="banner notice notice-warning" style="margin-top: 2rem;">
            <div class="banner-text">
                <h3>Do you need a full cache reset?</h3>
                <p style="margin-bottom: .5rem;"><b>Warning!</b> This operation is not immediate and will slow down the entire site and decrease performance until the cache is correctly repopulated.</p>
                <button id="purgeByPatternButton" class="button button-secondary">Clear cache</button>
                <div id="confirmationSection" style="display: none; margin-top: 1.3rem;">
                    <p style="margin-bottom: .5rem;">Are you sure you want to clear the cache?</p>
                    <button id="confirmClearCache" class="button button-primary">Yes</button>
                    <button id="cancelClearCache" class="button">No</button>
                </div>
            </div>
        </div>
    <?php
    }
    ?>
    <div class="banner notice notice-warning" style="margin-top: 2rem;">
        <div class="banner-text">
            <h3>How iSmasrtFrame plugin works</h3>
            <ul class="isf-ul">
                <li><strong>Automatic Cache Purge:</strong> Instantly clears cache when new content is published, or updates are made, ensuring only the updated page is affected.</li>
                <li><strong>Targeted Cache Management:</strong> Purges only the specific page cache or tag without clearing the entire website cache, keeping the rest of your site fast.</li>
                <li><strong>Customizable Cache Control:</strong> Allows for targeted cache purging by tags or custom URLs, giving you flexibility in managing what’s cached.</li>
                <li><strong>Complete Website Cache Clearing:</strong> Allows a global cleanup of the site. iSmartFrame retrieves the information directly from the origin server.</li>
            </ul>
            <p>Learn more on how <a href="https://www.ismartframe.com/en/features/">iSmartFrame</a> works.</p>
        </div>
    </div>
    <?php
}


/**
 * Render the logs page
 */
function renderPluginLogsPage() {
    // Check user capabilities
    if (!current_user_can('manage_options')) {
        wp_die(esc_html__('You do not have sufficient permissions to access this page.'));
    }

    // Initialize WP_Filesystem
    global $wp_filesystem;
    if (!function_exists('WP_Filesystem')) {
        require_once(ABSPATH . 'wp-admin/includes/file.php');
    }
    WP_Filesystem();

    // Define log file path
    $filename = plugin_dir_path(__DIR__) . 'ismartframe/isf-wordpress.log';

    // Read log file content
    $logContents = '';
    if ($wp_filesystem->exists($filename)) {
        $logContents = $wp_filesystem->get_contents($filename);
    }

?>
    <div class="wrap">
        <h1>iSmartFrame Plugin logs</h1>
        <p>Here you can view the last 24 hours logs from the iSmartFrame Plugin.</p>
        <textarea readonly rows="20" wrap="off" style="width: 100%; font-family: monospace; padding: 1rem;">
<?php
        echo esc_textarea($logContents);
?>
        </textarea>
    </div>
<?php
}


/**
 *
 * Create and add field for credentials
 *
 */
function registerPluginSettingsIsfWordpressApp() {
    register_setting('isfWordpressPluginOptions', 'isfWordpressPluginOptions');
    add_settings_section('api_settings', '', 'credentialsPageSectionIsfWordpressApp', 'isfWordpressOptions');
    add_settings_field('isfWordpressApiKey', 'Your API key', 'isfWordpressApiKey', 'isfWordpressOptions', 'api_settings', ['class' => 'w-100']);
    add_settings_field('isfWordpressDomain', 'Domain', 'isfWordpressDomain', 'isfWordpressOptions', 'api_settings', ['class' => 'w-100']);
    // add_settings_field( 'isfDebug', 'Debug', 'isfDebug', 'isfWordpressOptions', 'api_settings', ['class' => 'w-120'] );
}

add_action('admin_init', 'registerPluginSettingsIsfWordpressApp');

function credentialsPageSectionIsfWordpressApp() {
?>
    <div class="plugin-options-title">
        <h2>iSmartFrame plugin options</h2>
        <div class="spinner"></div>
    </div>
    <div class="message"></div>

<?php
    $options = get_option('isfWordpressPluginOptions');
    if (!isset($options['api_key']) || $options['api_key'] == '') {
        echo '<div class="notice notice-warning settings-error is-dismissible ml-0 mr-0"><p>Fill in all the fields to start using the plugin.</p></div>';
    }
}

function isfWordpressApiKey() {
    $options = get_option('isfWordpressPluginOptions');
    if (isset($options['api_key']) && $options['api_key'] != '') {
        echo "<input id='isfWordpressApiKey' required name='isfWordpressPluginOptions[api_key]' class='input-width' type='text' value='" . esc_attr($options['api_key']) . "' />";
    } else {
        echo "<input id='isfWordpressApiKey' required name='isfWordpressPluginOptions[api_key]' class='input-width' type='text' value='' />";
    }
}

function isfWordpressDomain() {
    echo "<input id='isfWordpressDomain' required readonly name='isfWordpressPluginOptions[domain]' class='input-width' type='text' value='" . esc_attr(wp_parse_url(get_site_url(), PHP_URL_HOST)) . "' />";
}


function isfDebug() {
    // $options = get_option( 'isfWordpressPluginOptions' );
    // if(is_array($options )) {
    //     if(isset($options['debug']) && esc_attr( $options['debug'] ) === "on"){
    //         echo "<input id='isfDebug'  name='isfWordpressPluginOptions[debug]' size='80' type='checkbox' checked />";
    //     } else {
    //         echo "<input id='isfDebug'  name='isfWordpressPluginOptions[debug]' size='80' type='checkbox' />";
    //     }
    // } else {
    //     echo "<input type='checkbox' id='isfDebug'  name='isfWordpressPluginOptions[debug]' size='80' checked  />";
    // }
}
